Structs
- Add actions to button widgets and other widgets to let the user initiate actions in the app.
Functions
- Launch a URL on the user’s device. The URL can point to a webpage or another app.
- Use
pollto update the page based on page data or backend data.