Struct applin::BackButton
source · pub struct BackButton {
pub actions: Vec<Action>,
}Fields
actions: Vec<Action>Trait Implementations
sourceimpl Clone for BackButton
impl Clone for BackButton
sourcefn clone(&self) -> BackButton
fn clone(&self) -> BackButton
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for BackButton
impl Debug for BackButton
sourceimpl<'de> Deserialize<'de> for BackButton
impl<'de> Deserialize<'de> for BackButton
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<BackButton> for Option<Widget>
impl From<BackButton> for Option<Widget>
sourcefn from(src: BackButton) -> Self
fn from(src: BackButton) -> Self
Converts to this type from the input type.
sourceimpl From<BackButton> for Widget
impl From<BackButton> for Widget
sourcefn from(src: BackButton) -> Self
fn from(src: BackButton) -> Self
Converts to this type from the input type.
sourceimpl Hash for BackButton
impl Hash for BackButton
sourceimpl Ord for BackButton
impl Ord for BackButton
sourcefn cmp(&self, other: &BackButton) -> Ordering
fn cmp(&self, other: &BackButton) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for BackButton
impl PartialEq for BackButton
sourcefn eq(&self, other: &BackButton) -> bool
fn eq(&self, other: &BackButton) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for BackButton
impl PartialOrd for BackButton
sourcefn partial_cmp(&self, other: &BackButton) -> Option<Ordering>
fn partial_cmp(&self, other: &BackButton) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for BackButton
impl Serialize for BackButton
impl Eq for BackButton
impl StructuralEq for BackButton
impl StructuralPartialEq for BackButton